MouseEvent

Struct MouseEvent 

#[non_exhaustive]
pub struct MouseEvent { pub kind: MouseEventKind, pub position: Pos, pub pixel_position: Option<PhysicalPos>, pub modifiers: KeyModifiers, }
Mouse input event.

Does not derive Eq/Hash: MouseEventKind does not (its Scroll variant’s f32 fields implement neither).

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
kind: MouseEventKind

The kind of mouse event.

position: Pos

Cell-grid position of the mouse cursor.

pixel_position: Option<PhysicalPos>

Physical pixel position of the mouse cursor, relative to the window’s top-left.

Populated by backends that support sub-cell precision (e.g. the software renderer). None on character-mode backends such as crossterm.

modifiers: KeyModifiers

Modifiers held down during the event.

Implementations

Source

impl MouseEvent

pub const fn new( kind: MouseEventKind, position: Pos, modifiers: KeyModifiers, ) -> Self

Creates a mouse event at the given cell-grid position, with no pixel position.

pub const fn with_pixel_position( kind: MouseEventKind, position: Pos, modifiers: KeyModifiers, pixel_position: PhysicalPos, ) -> Self

Creates a mouse event with an explicit pixel position, for backends with sub-cell precision.